sequencetools.CyclicMatrix
==========================

.. inheritance-diagram:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix
   :private-bases:

.. autoclass:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.columns

.. autoattribute:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.rows

.. autoattribute:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__getitem__

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.sequencetools.CyclicMatrix.CyclicMatrix.CyclicMatrix.__repr__
